@@ -5,10 +5,7 @@ Common parsing and testing functions.
 """
 
 import os
-import sys
-import shutil
-import tempfile
-import subprocess
+import copy
 import argparse
 import logging
 import ConfigParser
@@ -59,6 +56,15 @@ class Config(object):
             self.config[TRACKING][Config.ENVIRONMENTS] = envs
         self.updated = False
 
+    def copy(self):
+        """Return a new copy of the conifiguration.
+        @return: new Config
+        """
+        config = Config()
+        config.config = copy.deepcopy(self.config)
+        config.updated = copy.copy(self.updated)
+        return config
+
     def update(self, path):
         """Update the config from a config file.
         @param path: path to config file
@@ -342,50 +348,12 @@ def find_config(cwd, walk=False):
     @param walk: search recursively for a config
     @return: path or None
     """
-    for root, _dir, _filename in os.walk(cwd):
-        logging.debug(root)
+    for dirpath in (items[0] for items in os.walk(cwd)):
+        logging.debug(dirpath)
         for filename in ('setup.cfg', '.veracity'):
-            path = os.path.join(root, filename)
+            path = os.path.join(dirpath, filename)
             if os.path.isfile(path):
                 logging.debug("found config: {0}".format(path))
                 return path
         if not walk:
             return None
-
-
-def create_test_repo(name):  # pragma: no cover - not used every test iteration
-    """Creates a test repository for integration tests.
-    """
-    sys.stderr.write('\n' + "Creating a test repository for integration tests..." + '\n\n')
-    # Initialize a new repository
-    subprocess.call(['vv', 'repo', 'new', name])
-    subprocess.call(['vv', 'config', 'set', '/instance/{0}/paths/default'.format(name), name])
-    # Check out to a temporary location
-    temp = tempfile.mkdtemp()
-    os.chdir(temp)
-    subprocess.call(['vv', 'checkout', name])
-    # Commit 1
-    with open("foo.h", 'w') as new:
-        new.write("this is foo.h")
-    with open("bar.c", 'w') as new:
-        new.write("this is ")
-    subprocess.call(['vv', 'addremove'])
-    subprocess.call(['vv', 'whoami', '--create', 'testuser'])
-    subprocess.call(['vv', 'commit', '--message', "added sample files"])
-    # Commit 2
-    with open("bar.c", 'a') as new:
-        new.write("bar.c ")
-    subprocess.call(['vv', 'commit', '--message', "added missing text"])
-    # Initialize build configuration
-    os.chdir(os.path.dirname(__file__))
-    subprocess.call([sys.executable, 'vscript.py', name])
-    # Cleanup
-    shutil.rmtree(temp)
-    sys.stderr.write('\n')
-
-
-def delete_test_repo(name):  # pragma: no cover - not used every test iteration
-    """Delete the test repository.
-    """
-    sys.stderr.write('\n' + "Deleting the test repository..." + '\n\n')
-    subprocess.call(['vv', 'repo', 'delete', name])
