@@ -40,7 +40,7 @@ class _Base(object):  # pylint: disable=R0903
 class _BaseRepositoryObject(_Base):  # pylint: disable=R0903
     """Shared base class for objects that need a reference to the Repository."""
 
-    def __init__(self, create=True, repo=None, **_kwargs):
+    def __init__(self, create=True, repo=None, **_):
         if repo:
             if isinstance(repo, Repository):
                 self.repo = repo
@@ -80,7 +80,7 @@ class _BaseRepositorySpecObject(_BaseRepositoryObject):
 class _BaseWorkingCopyObject(_Base):  # pylint: disable=R0903
     """Shared base class for objects that need a reference to the WorkingCopy."""
 
-    def __init__(self, work=None, **_kwargs):
+    def __init__(self, work=None, **_):
         if work:
             if isinstance(work, WorkingCopy):
                 self.work = work
@@ -243,9 +243,8 @@ class Repository(_Base):
             else:
                 self._push_time = time.time()
 
-    @property
     @auto_pull
-    def branches(self):
+    def get_branches(self):
         """Return a list of branches in the repository.
         @return: list of Branches
         """
@@ -256,10 +255,10 @@ class Repository(_Base):
         for branch in branches:
             logging.debug("branch: {0}".format(branch))
         return branches
+    branches = property(get_branches)
 
-    @property
     @auto_pull
-    def history(self):
+    def get_history(self):
         """Return a list of changesets in the repository.
         @return: list of Changesets
         """
@@ -270,6 +269,7 @@ class Repository(_Base):
         for changeset in changesets:
             logging.debug("changeset: {0}".format(changeset))
         return changesets
+    history = property(get_history)
 
     @auto_pull
     def get_heads(self, branch=None):
@@ -290,42 +290,41 @@ class Repository(_Base):
         return changesets
     heads = property(get_heads)
 
-    @property
     @auto_pull
-    def leaves(self):  # pragma: no cover
+    def get_leaves(self):  # pragma: no cover
         raise NotImplementedError
+    leaves = property(get_leaves)
 
-    @property
     @auto_pull
-    def tags(self):
+    def get_tags(self):
         """Return a list of tags in the repository.
         @return: list of Tags
         """
         tags = []
         logging.debug("getting tags in repo '{n}'...".format(n=self.name))
-        for label, _local, rev in vv.parse(vv.run('tags', repo=self.name), 'tags'):
+        for label, _, rev in vv.parse(vv.run('tags', repo=self.name), 'tags'):
             tags.append(Tag(label, repo=self, rev=rev))
         for tag in tags:
             logging.debug("tag: {0}".format(tag))
         return tags
+    tags = property(get_tags)
 
-    @property
     @auto_pull
-    def stamps(self):
+    def get_stamps(self):
         """Return a list of stamps in the repository.
         @return: list of Stamps
         """
         stamps = []
         logging.debug("getting stamps in repo '{n}'...".format(n=self.name))
-        for label, _count in vv.parse(vv.run('stamps', repo=self.name), 'stamps'):
+        for label, _ in vv.parse(vv.run('stamps', repo=self.name), 'stamps'):
             stamps.append(Stamp(label, repo=self, identity=False))
         for stamp in stamps:
             logging.debug("stamp: {0}".format(stamp))
         return stamps
+    stamps = property(get_stamps)
 
-    @property
     @auto_pull
-    def users(self):
+    def get_users(self):
         """Return a list of users in the repository.
         @return: list of Users
         """
@@ -336,14 +335,15 @@ class Repository(_Base):
         for user in users:
             logging.debug("user: {0}".format(user))
         return users
+    users = property(get_users)
 
-    @property
     @auto_pull
-    def locks(self):  # pragma: no cover
+    def get_locks(self):  # pragma: no cover
         """Return a list of locked files in the repository.
         @return: list of Items
         """
         raise NotImplementedError
+    locks = property(get_locks)
 
     def get_user(self):
         """Return the current user for this repository.
@@ -587,9 +587,8 @@ class Repository(_Base):
             args = name, series, environment, status, cid, branch
         else:
             args = name, series, environment, status, cid
-        bid, cid, _name, _series, _environment = next(vscript.parse(vscript.report_build(self, 'new', *args),
-                                                                    style='builds'))
-        self.push()  # new build requests should always be pushed
+        bid, cid, name, series, environment = next(vscript.parse(vscript.report_build(self, 'new', *args),
+                                                                 style='builds'))
         return BuildRequest(bid, cid, name=name, series=series, environment=environment,
                             status=status, branch=branch, repo=self)
 
@@ -758,9 +757,8 @@ class WorkingCopy(_BaseRepositoryObject):
         shutil.copytree(self.path, path)
         return WorkingCopy(path, repo=self.repo)
 
-    @property
     @in_path
-    def branch(self):
+    def get_branch(self):
         """Get the currently attached branch.
         @return: current Branch
         """
@@ -769,6 +767,7 @@ class WorkingCopy(_BaseRepositoryObject):
             return Branch(name, repo=self.repo, identity=False)
         else:
             return None
+    branch = property(get_branch)
 
     @branch.setter
     def branch(self, name):
@@ -844,9 +843,8 @@ class WorkingCopy(_BaseRepositoryObject):
         return self.parents[0]
     parent = property(get_parent, doc='')
 
-    @property
     @in_path
-    def parents(self):
+    def get_parents(self):
         """Return a list of parent changesets.
         @return: list of parent Changesets
         """
@@ -857,6 +855,7 @@ class WorkingCopy(_BaseRepositoryObject):
         for changeset in changesets:
             logging.debug("changeset: {0}".format(changeset))
         return changesets
+    parents = property(get_parents)
 
     @in_path
     def status(self):
