@@ -61,6 +61,15 @@ class TestConfig(unittest.TestCase):  # pylint: disable=R0904
     def setUpClass(cls):
         cls.config = Config(os.path.join(FILES, 'setup.cfg'))
 
+    def test_copy(self):
+        """Verify a configuration can be copied."""
+        config1 = Config()
+        config2 = config1.copy()
+        config3 = config1
+        config1.updated = True
+        self.assertEqual(config1.updated, config3.updated)
+        self.assertNotEqual(config1.updated, config2.updated)
+
     def test_override(self):
         """Verify a configuration options can be overridden."""
         config = Config(os.path.join(FILES, 'setup.cfg'),
