@@ -9,7 +9,6 @@ import os
 import shutil
 import tempfile
 import logging
-from random import randrange
 
 from veracity import vv
 from veracity.vv import VeracityException
@@ -19,18 +18,14 @@ from veracity.objects import Repository, WorkingCopy, Item, Changeset, Branch, T
 from veracity.objects import BuildRequest
 from veracity import settings
 
-from veracity.test import TEST_REPO, REASON, log
+from veracity.test import TEST_REPO, REASON, log, temp_repo
 
 
 def setUpModule():  # pylint: disable=C0103
-    """Create a temporary, randomly-named repository for this module's tests.
+    """Create a temporary repository for this module's tests.
     """
     global TEMP_REPO  # pylint: disable=W0601
-    if TEST_REPO:
-        TEMP_REPO = TEST_REPO.clone(TEST_REPO.name + '-' + str(randrange(999)), autosync=False)
-        TEMP_REPO.user = 'testuser'
-    else:
-        TEMP_REPO = None
+    TEMP_REPO = temp_repo(__name__)
 
 
 def tearDownModule():  # pylint: disable=C0103
