@@ -7,24 +7,19 @@ Unit tests for the veracity.poller module.
 import unittest
 
 import os
-from random import randrange
 
 from veracity.poller import Poller, run
 from veracity.objects import Changeset, Branch
 from veracity.common import Config
 
-from veracity.test import TEST_REPO, REASON, FILES, log
+from veracity.test import TEST_REPO, REASON, FILES, log, temp_repo
 
 
 def setUpModule():  # pylint: disable=C0103
-    """Create a temporary, randomly-named repository for this module's tests.
+    """Create a temporary repository for this module's tests.
     """
     global TEMP_REPO  # pylint: disable=W0601
-    if TEST_REPO:
-        TEMP_REPO = TEST_REPO.clone(TEST_REPO.name + '-' + str(randrange(999)), autosync=False)
-        TEMP_REPO.user = 'testuser'
-    else:
-        TEMP_REPO = None
+    TEMP_REPO = temp_repo(__name__)
 
 
 def tearDownModule():  # pylint: disable=C0103
