@@ -31,7 +31,7 @@ except ImportError:  # pragma: no cover - only occurs with missing dependency
     raise EnvironmentError("vscript is not installed")
 
 
-SCRIPTS_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'files')
+SCRIPT_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'files')
 INIT_BUILDS_JS = 'init_builds.js'
 REPORT_BUILD_JS = 'report_build.js'
 
@@ -46,7 +46,7 @@ def init_builds(repo):
     @param repo: name of repository
     @return: output from script
     """
-    os.chdir(SCRIPTS_DIR)
+    os.chdir(SCRIPT_DIR)
     return run(INIT_BUILDS_JS, repo)
 
 
@@ -56,7 +56,7 @@ def report_build(repo, *args):
     @param args: additional arguments
     @return: output from script
     """
-    os.chdir(SCRIPTS_DIR)
+    os.chdir(SCRIPT_DIR)
     try:
         return run(REPORT_BUILD_JS, repo, *args)
     except VeracityScriptException as exception:
@@ -81,8 +81,10 @@ def run(*args, **kwargs):
     try:
         result = command()
     except ErrorReturnCode as erc:
-        msg = "\n\nIN: {0}\n\nRAN: {1}\n\nOUTPUT:{2}\n".format(os.getcwd(), erc.full_cmd,
-                                                               erc.stdout.strip() or erc.stderr.strip())
+        msg = ("\n\nIN: {0}"
+               "\n\nRAN: {1}"
+               "\n\nOUTPUT:{2}\n").format(os.getcwd(), erc.full_cmd,
+                                          (erc.stdout or erc.stderr).strip())
         raise VeracityScriptException(msg)
     else:
         return result.stdout.strip()
@@ -97,10 +99,18 @@ def parse(output, style=None):
 
         if 'builds' in data:
             for record in data['builds']:
-                yield record['recid'], record['csid'], record['name'], record['series'], record['environment']
+                yield (record['recid'],
+                       record['csid'],
+                       record['name'],
+                       record['series'],
+                       record['environment'])
         elif 'build' in data:
             record = data['build']
-            yield record['recid'], record['csid'], record['name'], record['series'], record['environment']
+            yield (record['recid'],
+                   record['csid'],
+                   record['name'],
+                   record['series'],
+                   record['environment'])
         else:
             logging.debug("no build data: {0}".format(repr(data)))
 
